pub struct ChatbotUserContext {
pub user_id: Uuid,
pub course_id: Uuid,
pub course_name: String,
}Expand description
Context about the user and course for a chatbot interaction. Passed to tool implementations so they can access user-specific data.
Fields
user_id: Uuidcourse_id: Uuidcourse_name: StringAuto Trait Implementations
impl Freeze for ChatbotUserContext
impl RefUnwindSafe for ChatbotUserContext
impl Send for ChatbotUserContext
impl Sync for ChatbotUserContext
impl Unpin for ChatbotUserContext
impl UnwindSafe for ChatbotUserContext